# Changelog

## 0.2.0 (2025-11-03)

Full Changelog: [v0.1.0...v0.2.0](https://github.com/Henry-Social/henry-sdk-py/compare/v0.1.0...v0.2.0)

### Features

* **api:** api update ([9324dd0](https://github.com/Henry-Social/henry-sdk-py/commit/9324dd0fe067e45a6c155156fb8d2437f4b25b4c))
* **api:** api update ([445c7c5](https://github.com/Henry-Social/henry-sdk-py/commit/445c7c5484eb1185806764c3e195a4959f8e9411))
* **api:** api update ([e437724](https://github.com/Henry-Social/henry-sdk-py/commit/e437724becfe9db0cc005d2704d7ff42199f251c))
* **api:** api update ([87d4fc0](https://github.com/Henry-Social/henry-sdk-py/commit/87d4fc08c1272ff894212cc7b021911d96898ed4))
* **api:** api update ([5ef4d15](https://github.com/Henry-Social/henry-sdk-py/commit/5ef4d15470af8250c5155b5aeb44484a41134b3c))
* **api:** manual updates ([f5b90fb](https://github.com/Henry-Social/henry-sdk-py/commit/f5b90fb2c0724f62f20d5f32c539e12dee005b35))
* **api:** manual updates ([6ac7914](https://github.com/Henry-Social/henry-sdk-py/commit/6ac7914b742817c4f92bad80f50960bca7178d1b))
* **api:** manual updates ([dd883b9](https://github.com/Henry-Social/henry-sdk-py/commit/dd883b9e5ba5c4646486ad7ecd037f51c5fc7172))
* **api:** manual updates ([a03cd1f](https://github.com/Henry-Social/henry-sdk-py/commit/a03cd1f81fe9b9ac4d84d393d07e319762aad16c))


### Bug Fixes

* **client:** close streams without requiring full consumption ([a123715](https://github.com/Henry-Social/henry-sdk-py/commit/a12371587722105a95b70486bcc312019166aead))


### Chores

* **internal/tests:** avoid race condition with implicit client cleanup ([0d931e3](https://github.com/Henry-Social/henry-sdk-py/commit/0d931e3acd02a96058def00f57e961e3639a1f1a))

## 0.1.0 (2025-10-28)

Full Changelog: [v0.0.1...v0.1.0](https://github.com/Henry-Social/henry-sdk-py/compare/v0.0.1...v0.1.0)

### Chores

* configure new SDK language ([4be628a](https://github.com/Henry-Social/henry-sdk-py/commit/4be628a8197ffc24748f2dc6e2d29971676ffb04))
* update SDK settings ([eab8148](https://github.com/Henry-Social/henry-sdk-py/commit/eab81481d9faf4036c1cbdd243cdc3175b443730))
* update SDK settings ([1bb30aa](https://github.com/Henry-Social/henry-sdk-py/commit/1bb30aa4a7d6b94ec7e00393b71de9b21f4540de))
